@@ -195,6 +195,7 @@ UBX_MSGIDS = {
     # External Sensor Fusion messages
     # ***************************************************************
     b"\x10\x14": "ESF-ALG",
+    b"\x10\x04": "ESF-CAL",
     b"\x10\x15": "ESF-INS",
     b"\x10\x02": "ESF-MEAS",
     b"\x10\x03": "ESF-RAW",
@@ -362,6 +363,10 @@ UBX_MSGIDS = {
     b"\x02\x34": "RXM-COR",
     b"\x02\x31": "RXM-EPH",  # obsolete, use AID-EPH or MGA-*-EPH
     b"\x02\x61": "RXM-IMES",
+    b"\x02\x84": "RXM-MEAS20",
+    b"\x02\x86": "RXM-MEAS50",
+    b"\x02\x82": "RXM-MEASC12",
+    b"\x02\x80": "RXM-MEASD12",
     b"\x02\x14": "RXM-MEASX",
     b"\x02\x72": "RXM-PMP",  # 2 versions
     b"\x02\x41": "RXM-PMREQ",  # 2 versions
